var $ = require('gulp-load-plugins')();
var gulp = require('gulp');
var gutil = require('gulp-util');
var less = require('gulp-less');
var replace = require('gulp-replace');
var minifyCSS = require('gulp-minify-css');
var shell = require('gulp-shell');
var fileinclude = require('gulp-file-include');
var autoprefixer = require('gulp-autoprefixer');

var wpPot = require('gulp-wp-pot');
var sort = require('gulp-sort');

var paths = {
	scripts: 'js/**/*.js',
	images: 'img/**/*',
	less: 'styles/less/**/*.less',
	css: 'css/custom.css',
	html: 'src/*.html',
	docs: 'documentation/src/*.html',
	fonts: 'fonts/**/*',
	includes: 'inc/**/*',
	javascripts: [
		'js/browser.js',
		'js/jquery.waitforimages.min.js',
		'js/masonry.js',
		'js/isotope.pkgd.min.js',
		'js/masonry.pkgd.min.js',
		'js/navigation.js',
		'js/skip-link-focus-fix.js',
		'js/jquery.ba-throttle-debounce.min.js',
		'js/jquery.smooth-scroll.js',
		'js/matchmedia.js',
		'js/enquire.min.js',
		'js/jquery.velocity.min.js',
		'js/waypoints.js',
		'js/owl.carousel.js',
		'js/swiper.jquery.min.js',
		'js/jquery.mb.YTPlayer.js',
		'js/jquery.parallax.js',
		'js/jquery.imagesloaded.js',
		'js/jquery.unveil.min.js',
		// 'js/jquery.prettyPhoto.js',
		'js/jquery.superslides.min.js',
		'js/jquery.fullPage.min.js',
		'js/jquery.mixitup.js',
		// 'js/picker.js',
		// 'js/picker.date.js',
		// 'js/picker.time.js',
	]
};


gulp.task('build-docs', function() {
	gulp.src(['documentation/src/*.html'])
	.pipe(fileinclude({
		prefix: '@@',
		basepath: '@file'
	}))
	.on('error', function(err) { gutil.log(err.message); })
	.pipe(replace(/@@([A-Za-z])\w+/g, ''))
	.pipe(gulp.dest('./documentation/'))
	.pipe(shell('rm -f ./documentation/_*.html'));
});

// Build less for development and demo
gulp.task('build-less', function() {
	return gulp.src('styles/less/custom.less')
	.pipe(less())
	.on('error', function(err) { gutil.log(err.message); })
	.pipe(replace(/\|\|[a-zA-Z0-9./:-]+/g, ''))
	.pipe(autoprefixer('last 2 version', 'safari 5', 'ie 8', 'ie 9', 'opera 12.1', 'ios 6', 'android 4'))
	.pipe(minifyCSS({
		keepBreaks:false,
		keepSpecialComments:0,
	}))
	.pipe(gulp.dest('./styles/css'));
});

gulp.task('js-libs', function() {
  var uglify = $.uglify()
    .on('error', $.notify.onError({
      message: "<%= error.message %>",
      title: "Uglify JS Error"
    }));

  return gulp.src(paths.javascripts)
    // .pipe($.sourcemaps.init())
    .pipe($.babel())
    .pipe($.concat('libs.js', {
      newLine:'\n;'
    }))
    .pipe(uglify)
    .pipe(gulp.dest('js/'));
    // .pipe(browserSync.stream());
});

// Generate pot file for translation
gulp.task('pot', function () {
	return gulp.src('**/*.php')
		.pipe(sort())
		.pipe(wpPot( {
			domain: 'BERG',
			destFile:'berg-wp.pot',
			package: 'BERG',
			bugReport: 'http://yosupport.freshdesk.com/',
			lastTranslator: 'yosoftware',
			team: 'yosoftware'
		} ))
		.pipe(gulp.dest('languages'));
});

// Rerun the task when a file changes
gulp.task('watch', function() {
	gulp.watch(paths.less, ['build-less']);
	gulp.watch(paths.docs, ['build-docs']);

});

gulp.task('default', ['watch']);