<?php
/**
 * Google Maps shortcode
 */

class Berg_Gmaps_Shortcode {

	public function __construct(){
		add_shortcode( 'berg_gmaps', array( $this, 'google_maps' ) );
		add_action('wp_enqueue_scripts',array($this,'front_scripts'));

		// if(defined('WPB_VC_VERSION')) {
		add_action('vc_before_init', array($this, 'google_map_config'));
		// }
	}
	function front_scripts(){
		global $post;
		if (!is_page()) {
			return;
		}
		if(!is_404() && !is_search()){
			$key = '';
			$apiKey = YSettings::g('berg_contact_google_api_key');
			if($apiKey != '') {
				$key = '?key='.$apiKey;
			}
			wp_enqueue_script("google-maps-shortcode","https://maps.googleapis.com/maps/api/js$key","1.0",array(),false);
		}
	}

	public function google_maps( $atts, $content = null ) {
		$width = $size = $map_type = $lat = $lng = $zoom = $controls = $top_margin = $marker_icon = $icon_img = $output = $map_style = $scrollwheel = $css_class = '';

		extract(shortcode_atts(array(
			"size" => "300px",
			"berg_contact_markers" => "40.7143528 -74.0059731",
			"map_type" => "ROADMAP",
			"lat" => "50.84984",
			"lng" => "16.47568",
			"scrollwheel" => "false",
			"controls" => "false",
			"map_zoom" => 14,
			"marker_icon" => "",
			"icon_img" => "",
			"map_style" => "",
			"css_class" => "",
		), $atts));

		$marker_lat = $lat;
		$marker_lng = $lng;
		if($marker_icon == "default"){
			$icon_url = "";
		} else {
			$ico_img = wp_get_attachment_image_src( $icon_img, 'large');
			$icon_url = $ico_img[0];
		}

		$id = "map_".uniqid();
		$wrap_id = "wrap_".$id;
		$map_type = strtoupper($map_type);
		$map_height = (substr($size, -1)!="%" && substr($size, -2)!="px" ? $size . "px" : $size);
		$output .= '<div id="'.$wrap_id.'" class="map-wrapper '.$css_class.'" style=" '.($map_height!='' ? 'height: ' . $map_height . ';' : '').'">

			<div id="' . $id . '" class="berg-google-map" ' . ($map_height!='' ? ' style="' . ($map_height!='' ? 'height:' . $map_height . ';' : '') .'' : '') . '">
			</div>
		</div>';

		$berg_contact_locations = array();
		$berg_contact_markers = explode(",", $berg_contact_markers);
		foreach ($berg_contact_markers as $value) {
			$value = trim($value);
			$berg_contact_locations[] = explode(" ", $value); 
		}

		$output .= "<script type='text/javascript'>

		CustomMarker.prototype = new google.maps.OverlayView();

		function CustomMarker(opts) {
		    this.setValues(opts);
		}

		CustomMarker.prototype.draw = function() {
		    var self = this;
		    var div = this.div;
		    if (!div) {
		        div = this.div = jQuery('' +
		            '<div>' +
		            '<div class=\"shadow\"></div>' +
		            '<div class=\"pulse\"></div>' +
		            '<div class=\"pin-wrap\">' +
		            '<div class=\"pin\"></div>' +
		            '</div>' +
		            '</div>' +
		            '')[0];
		        this.pinWrap = this.div.getElementsByClassName('pin-wrap');
		        this.pin = this.div.getElementsByClassName('pin');
		        this.pinShadow = this.div.getElementsByClassName('shadow');
		        div.style.position = 'absolute';
		        div.style.cursor = 'pointer';
		        var panes = this.getPanes();
		        panes.overlayImage.appendChild(div);
		        google.maps.event.addDomListener(div, \"click\", function(event) {
		            google.maps.event.trigger(self, \"click\", event);
		        });
		    }
		    var point = this.getProjection().fromLatLngToDivPixel(this.position);
		    if (point) {
		        div.style.left = point.x + 'px';
		        div.style.top = point.y + 'px';
		    }
		};

		var map_$id = null;
		try
		{			
			var map_$id = null;
			var mapOptions = '';
			var locations = ".json_encode($berg_contact_locations).";
			var mapLocations = jQuery.extend({}, locations );

			mapOptions = 
			{
				scaleControl: true,
				streetViewControl: $controls,
				mapTypeControl: $controls,
				panControl: $controls,
				zoomControl: $controls,
				scrollwheel: $scrollwheel,
				";
				if($map_style == ""){
					$output .= "mapTypeId: google.maps.MapTypeId.$map_type,";
				} else {
					$output .= " mapTypeControlOptions: {
				  		mapTypeIds: [google.maps.MapTypeId.$map_type, 'map_style']
					}";
				}
			$output .= "};";
			if($map_style !== ""){
			$output .= 'var styles = '.rawurldecode(base64_decode(strip_tags($map_style))).';
					var styledMap = new google.maps.StyledMapType(styles,
				    	{name: "Styled Map"});
					';
			}
			$output .= "var map_$id = new google.maps.Map(document.getElementById('$id'),mapOptions);";
			if($map_style !== ""){
			$output .= "map_$id.mapTypes.set('map_style', styledMap);
							 map_$id.setMapTypeId('map_style');";
			}
			
			$output .= "
			var latLngBounds = new google.maps.LatLngBounds();
			jQuery.each(mapLocations, function(key, value) {
				
				var markerImage = value.marker;
				var latLng = new google.maps.LatLng(value[0], value[1]);
				latLngBounds.extend(latLng);

				var mapOptions = {
					position: latLng,
					animation:  google.maps.Animation.DROP,
					map: map_$id,
					icon: '$icon_url'
				};

				".(($marker_icon == "default") ? "var marker = new CustomMarker(mapOptions);" : "var marker = new google.maps.Marker(mapOptions);")."			

			});
			map_$id.setZoom(1);
			map_$id.initialZoom = true;
			var listener = google.maps.event.addListener(map_$id, 'idle', function() {
				map_$id.fitBounds(latLngBounds);
				var markers = Object.keys(mapLocations);
				var markerCount = markers.length;
				map_$id.initialZoom = false;
				if(markerCount == 1) {
					map_$id.setZoom($map_zoom);
				}
				if(map_$id.getZoom() > 15 && markerCount > 1) {
					map_$id.setZoom(16);
				}
				google.maps.event.removeListener(listener);
			});
			jQuery(window).on('resize', function() {
				map_$id.fitBounds(latLngBounds);
				var markers = Object.keys(mapLocations);
				var markerCount = markers.length;
				map_$id.setZoom(map_$id.getZoom() -1);
				map_$id.initialZoom = false;
				if(markerCount == 1) {
					map_$id.setZoom($map_zoom);
				}
				if(map_$id.getZoom() > 15 && markerCount > 1) {
					map_$id.setZoom(16);
				}
			});

			jQuery(window).on('load', function() {
				google.maps.event.trigger(map_$id, 'resize');
				map_$id.fitBounds(latLngBounds);
				var markers = Object.keys(mapLocations);
				var markerCount = markers.length;
				map_$id.setZoom(map_$id.getZoom() -1);
				map_$id.initialZoom = false;
				if(markerCount == 1) {
					map_$id.setZoom($map_zoom);
				}
				if(map_$id.getZoom() > 15 && markerCount > 1) {
					map_$id.setZoom(16);
				}
			});

		}
		catch(e){};
		
		</script>";
		return $output;

	}

	function google_map_config() {
		if(!function_exists('vc_map')) {
			return;
		}
		vc_map( array(
			'name' => __( 'Berg Google Maps', 'berg' ),
			'base' => 'berg_gmaps',
			'icon' => 'icon-wpb-map-pin',
			'category' => __( 'Content', 'berg' ),
			'description' => __( 'Map block', 'berg' ),
			'params' => array(
				array(
					'type'     => 'textarea',
					'param_name'       => 'berg_contact_markers',
					'heading'    => __( 'Markers positions', 'berg' ),
					'value'  => '40.7143528 -74.0059731',
					
					'description' => __('Insert latitude and longitude of a point. An example of website where you get geolocation: <a href="http://mondeca.com/index.php/en/any-place-en">Click here</a>. If you want to add multi contact, insert comma between positions.', 'berg'),
				),
				array(
					'type' => 'textfield',
					'heading' => __( 'Map height', 'berg' ),
					'param_name' => 'size',
					'value' => '300px',
					'admin_label' => true,
					'description' => __( 'Enter map height in pixels.', 'berg' ),
				),
				array(
					"type" => "dropdown",
					"class" => "",
					"heading" => __('Map type', 'berg'),
					"param_name" => "map_type",
					"admin_label" => true,
					"value" => array(__("Roadmap", 'berg') => "ROADMAP", __("Satellite", 'berg') => "SATELLITE", __("Hybrid", 'berg') => "HYBRID", __("Terrain", 'berg') => "TERRAIN"),
				),
				array(
					"type" => "dropdown",
					"heading" => __("Map Zoom", 'berg'),
					"param_name" => "map_zoom",
					'description' => __('Insert map zoom if is only one marker point.', 'berg'),
					"value" => array(
						1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20
					),
					"std" => 14,
				),
				array(
					"type" => "dropdown",
					"heading" => __("Map zoom on mouse wheel scroll", 'berg'),
					"param_name" => "scrollwheel",
					"value" => array(__("Disable", 'berg') => "false", __("Enable", 'berg') => "true"),
				),
				array(
					"type" => "dropdown",
					"class" => "",
					"heading" => __("Show controls", 'berg'),
					"param_name" => "controls",
					"value" => array(__("Disable", 'berg') => "false", __("Enable", 'berg') => "true"),
				),
				array(
					"type" => "dropdown",
					"class" => "",
					"heading" => __("Marker/Point icon", 'berg'),
					"param_name" => "marker_icon",
					"value" => array(__("Use Google Default", 'berg') => "default", __("Upload Custom", 'berg') => "custom"),
				),
				array(
					"type" => "attach_image",
					"class" => "",
					"heading" => __("Upload Image Icon:", 'berg'),
					"param_name" => "icon_img",
					"admin_label" => true,
					"value" => "",
					"description" => __("Upload the custom image icon.", 'berg'),
					"dependency" => array("element" => "marker_icon","value" => array("custom")),
				),
				array(
					"type" => "textarea_raw_html",
					"class" => "",
					"heading" => "Google Styled Map JSON",
					"param_name" => "map_style",
					"value" => "",
					"description" => __("<a target='_blank' href='https://snazzymaps.com/'>Click here</a> to get the style JSON code for styling your map.", 'berg'),
					"group" => __("Custom style", 'berg'),
				),
				array(
					'type' => 'textfield',
					'heading' => __( 'Extra class name', 'berg' ),
					'param_name' => 'el_class',
					'description' => __( 'Style particular content element differently - add a class name and refer to it in custom CSS.', 'berg' ),
				),
			),
		) );
	}

}

new Berg_Gmaps_Shortcode();